@@ -55,6 +55,13 @@ def _write_read_supcmu_i2c(i2c_master: I2CMaster,
 
 
 def get_version_string(i2c_master: I2CMaster, address: int) -> str:
+    """
+    Gets the version string for the module at the provided address
+
+    :param i2c_master: The I2CMaster to use.
+    :param address: The address of the device to request information from.
+    :return: The version string
+    """
     module_def = SupMCUModuleDefinition("", "", address, {0: SUPMCU_VERSION_DEFINITION}, {})
     master = SupMCUMaster(i2c_master, (module_def,))
     version = master.request_telemetry(address, TelemetryType.SupMCU, 0).items[0].value
@@ -63,14 +70,27 @@ def get_version_string(i2c_master: I2CMaster, address: int) -> str:
 
 
 def get_values(i2c_master: I2CMaster, address: int, module_cmd_name: str, idx: int, format: str, response_delay: Optional[float] = None) -> List[TelemetryDataItem]:
+    """
+    Retrieves the current values of the telemetry object that is indicated by the provided index
+
+    :param i2c_master: The I2CMaster device to use.
+    :param address: The address of the device to request information from.
+    :param module_cmd_name: The module name used in the context of SCPI commands (e.g. DCPS for Desktop CubeSat Power
+                            Supply).
+    :param idx: The telemetry index to grab the information for.
+    :param response_delay: The amount of time in seconds to wait between I2C Write and read. Can be None, or set
+                            from SupMCUMaster passed in as `i2c_master`.
+    :return: A list of :any:`TelemetryDataItem`
+    """
+    if response_delay is None:
+        # None was set by the SupMCU master or the passed in variable.
+        response_delay = _DEFAULT_RESPONSE_DELAY
     try:
         size = _format_to_length(format) + SIZEOF_HEADER_FOOTER
     except ValueError:
         # Size of version string
         size = SUPMCU_VERSION_DEFINITION.telemetry_length
     # size = SIZEOF_HEADER_FOOTER + sum((_data_type_sizes[f] for f in fmt))
-    print(size)
-    print(format)
     raw_bytes = _write_read_supcmu_i2c(i2c_master, address, f'{module_cmd_name}:TEL? {idx}\n',
         size, response_delay)
     # raw_bytes = raw_bytes[SIZEOF_HEADER_FOOTER:]
